==> react-10.0.0.tgz: package/es/Loading/index.js <==
import "core-js/modules/es6.string.small";
import React from 'react';
import PropTypes from 'prop-types';
/**
 * @category communication
 * @component loading-spinner
 * @variations collab-ui-react
 */

var Loading = function Loading(props) {
  var small = props.small;
  return React.createElement("div", {
    className: "cui-loading " + (small ? 'cui-loading--small' : '')
  }, React.createElement("span", {
    className: "cui-loading__icon"
  }), React.createElement("span", {
    className: "cui-loading__icon"
  }), React.createElement("span", {
    className: "cui-loading__icon"
  }));
};

Loading.propTypes = {
  /** @prop Prop to make the Loading animation small | false */
  small: PropTypes.bool
};
Loading.defaultProps = {
  small: false
};
Loading.displayName = 'Loading';
export default Loading;
/**
* @name Default Loading
* @description Loadings are useful.
*
* @category communication
* @component loader-spinner
* @section default
*
* @js
import { Loading } from '@collab-ui/react';

export default function Default() {
  return (
    <div className="row">
      <div className="docs-example docs-example--spacing" style={{fontSize: '1rem', display: 'flex'}}>
        <Loading />
      </div>
      <div className="docs-example docs-example--spacing" style={{fontSize: '2rem', display: 'flex'}}>
        <Loading />
      </div>
      <div className="docs-example docs-example--spacing" style={{fontSize: '3rem', display: 'flex'}}>
        <Loading />
      </div>
    </div>
  );
}

**/

==> react-10.0.9.tgz: package/es/Loading/index.js <==
import "core-js/modules/es6.string.small";
import React from 'react';
import PropTypes from 'prop-types';
/**
 * @category communication
 * @component loading-spinner
 * @variations collab-ui-react
 */

var Loading = function Loading(props) {
  var small = props.small;
  return React.createElement("div", {
    className: "cui-loading " + (small ? 'cui-loading--small' : '')
  }, React.createElement("span", {
    className: "cui-loading__icon"
  }), React.createElement("span", {
    className: "cui-loading__icon"
  }), React.createElement("span", {
    className: "cui-loading__icon"
  }));
};

Loading.propTypes = {
  /** @prop Prop to make the Loading animation small | false */
  small: PropTypes.bool
};
Loading.defaultProps = {
  small: false
};
Loading.displayName = 'Loading';
export default Loading;
/**
* @name Default Loading
* @description Loadings are useful.
*
* @category communication
* @component loader-spinner
* @section default
*
* @js
import { Loading } from '@collab-ui/react';

export default function LoaderSpinnerDefault() {
  return (
    <div className="row">
      <div className="docs-example docs-example--spacing" style={{fontSize: '1rem', display: 'flex'}}>
        <Loading />
      </div>
      <div className="docs-example docs-example--spacing" style={{fontSize: '2rem', display: 'flex'}}>
        <Loading />
      </div>
      <div className="docs-example docs-example--spacing" style={{fontSize: '3rem', display: 'flex'}}>
        <Loading />
      </div>
    </div>
  );
}

**/
